==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/Containers/AmazonElasticContainerRegistryImage.md <==
# AmazonElasticContainerRegistryImage


```text
aws-q3-2021/Resource/Containers/AmazonElasticContainerRegistryImage
```

```text
include('aws-q3-2021/Resource/Containers/AmazonElasticContainerRegistryImage')
```



| Illustration | AmazonElasticContainerRegistryImage | AmazonElasticContainerRegistryImageCard | AmazonElasticContainerRegistryImageGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Containers/AmazonElasticContainerRegistryImage.png) | ![illustration for AmazonElasticContainerRegistryImage](../../../aws-q3-2021/Resource/Containers/AmazonElasticContainerRegistryImage.Local.png) | ![illustration for AmazonElasticContainerRegistryImageCard](../../../aws-q3-2021/Resource/Containers/AmazonElasticContainerRegistryImageCard.Local.png) | ![illustration for AmazonElasticContainerRegistryImageGroup](../../../aws-q3-2021/Resource/Containers/AmazonElasticContainerRegistryImageGroup.Local.png) |




## AmazonElasticContainerRegistryImage

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerRegistryImage
include('aws-q3-2021/Resource/Containers/AmazonElasticContainerRegistryImage')

' renders the element
AmazonElasticContainerRegistryImage('AmazonElasticContainerRegistryImage', 'Amazon Elastic Container Registry Image', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerRegistryImage
include('aws-q3-2021/Resource/Containers/AmazonElasticContainerRegistryImage')

' renders the element
AmazonElasticContainerRegistryImage('AmazonElasticContainerRegistryImage', 'Amazon Elastic Container Registry Image', 'an optional tech label')
@enduml
```

## AmazonElasticContainerRegistryImageCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerRegistryImageCard
include('aws-q3-2021/Resource/Containers/AmazonElasticContainerRegistryImage')

' renders the element
AmazonElasticContainerRegistryImageCard('AmazonElasticContainerRegistryImageCard', 'Amazon Elastic Container Registry Image Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerRegistryImageCard
include('aws-q3-2021/Resource/Containers/AmazonElasticContainerRegistryImage')

' renders the element
AmazonElasticContainerRegistryImageCard('AmazonElasticContainerRegistryImageCard', 'Amazon Elastic Container Registry Image Card', 'an optional description')
@enduml
```

## AmazonElasticContainerRegistryImageGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerRegistryImageGroup
include('aws-q3-2021/Resource/Containers/AmazonElasticContainerRegistryImage')

' renders the element
AmazonElasticContainerRegistryImageGroup('AmazonElasticContainerRegistryImageGroup', 'Amazon Elastic Container Registry Image Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerRegistryImageGroup
include('aws-q3-2021/Resource/Containers/AmazonElasticContainerRegistryImage')

' renders the element
AmazonElasticContainerRegistryImageGroup('AmazonElasticContainerRegistryImageGroup', 'Amazon Elastic Container Registry Image Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-7.1.0.tgz: package/distribution/aws-q1-2022/Resource/Containers/AmazonElasticContainerRegistryImage.md <==
# AmazonElasticContainerRegistryImage


```text
aws-q1-2022/Resource/Containers/AmazonElasticContainerRegistryImage
```

```text
include('aws-q1-2022/Resource/Containers/AmazonElasticContainerRegistryImage')
```



| Illustration | AmazonElasticContainerRegistryImage | AmazonElasticContainerRegistryImageCard | AmazonElasticContainerRegistryImageGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q1-2022/Resource/Containers/AmazonElasticContainerRegistryImage.png) | ![illustration for AmazonElasticContainerRegistryImage](../../../aws-q1-2022/Resource/Containers/AmazonElasticContainerRegistryImage.Local.png) | ![illustration for AmazonElasticContainerRegistryImageCard](../../../aws-q1-2022/Resource/Containers/AmazonElasticContainerRegistryImageCard.Local.png) | ![illustration for AmazonElasticContainerRegistryImageGroup](../../../aws-q1-2022/Resource/Containers/AmazonElasticContainerRegistryImageGroup.Local.png) |




## AmazonElasticContainerRegistryImage

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerRegistryImage
include('aws-q1-2022/Resource/Containers/AmazonElasticContainerRegistryImage')

' renders the element
AmazonElasticContainerRegistryImage('AmazonElasticContainerRegistryImage', 'Amazon Elastic Container Registry Image', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerRegistryImage
include('aws-q1-2022/Resource/Containers/AmazonElasticContainerRegistryImage')

' renders the element
AmazonElasticContainerRegistryImage('AmazonElasticContainerRegistryImage', 'Amazon Elastic Container Registry Image', 'an optional tech label')
@enduml
```

## AmazonElasticContainerRegistryImageCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerRegistryImageCard
include('aws-q1-2022/Resource/Containers/AmazonElasticContainerRegistryImage')

' renders the element
AmazonElasticContainerRegistryImageCard('AmazonElasticContainerRegistryImageCard', 'Amazon Elastic Container Registry Image Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerRegistryImageCard
include('aws-q1-2022/Resource/Containers/AmazonElasticContainerRegistryImage')

' renders the element
AmazonElasticContainerRegistryImageCard('AmazonElasticContainerRegistryImageCard', 'Amazon Elastic Container Registry Image Card', 'an optional description')
@enduml
```

## AmazonElasticContainerRegistryImageGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerRegistryImageGroup
include('aws-q1-2022/Resource/Containers/AmazonElasticContainerRegistryImage')

' renders the element
AmazonElasticContainerRegistryImageGroup('AmazonElasticContainerRegistryImageGroup', 'Amazon Elastic Container Registry Image Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AmazonElasticContainerRegistryImageGroup
include('aws-q1-2022/Resource/Containers/AmazonElasticContainerRegistryImage')

' renders the element
AmazonElasticContainerRegistryImageGroup('AmazonElasticContainerRegistryImageGroup', 'Amazon Elastic Container Registry Image Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
